@@ -3,6 +3,10 @@ from typing import Tuple, List, Optional
 from collections import OrderedDict
 from random import randrange
 
+from dovado_rtl.antlr.hdl_representation import (
+    ParameterType,
+    ParameterTypeEnum,
+)
 from dovado_rtl.config import Configuration
 import dovado_rtl.vivado_interaction as vivado
 from dovado_rtl.frame_handling import (
@@ -27,6 +31,8 @@ from dovado_rtl.cli_utility import (
 )
 import typer
 
+from dovado_rtl.src_parsing import SourceParser
+
 app = typer.Typer(help="Dovado RTL design automation and space exploration")
 vivado.start()
 
@@ -262,13 +268,27 @@ def space(
         help="controller to use for fitness function approximation (see movado docs for more information),"
         + "'Distance' is default. 'Mab' selects a pure multi-armed bandit controller",
     ),
-    controller_mab_weight: Optional[bool] = typer.Option(
-        False, help="enable loss weighting in Distance Controller"
+    disable_controller_mab_weight: Optional[bool] = typer.Option(
+        False, help="disable loss weighting in Distance Controller"
     ),
 ):
     """
     RTL design space exploration
     """
+    for idx, param in enumerate(ctx.obj["parameters"]):
+        parsed_src: SourceParser = ctx.obj["point_evaluator"].get_parsed_src()
+        full_param = parsed_src.get_parameter(param)
+        if full_param.get_type().type is ParameterTypeEnum.BOOL:
+            param_ranges = (
+                list(param_ranges[: idx * 2])
+                + [0, 1]
+                + (
+                    list(param_ranges[idx * 2 :])
+                    if (idx * 2) < len(param_ranges)
+                    else []
+                )
+            )
+
     it = iter(param_ranges)
     ranges_dict = OrderedDict(zip(ctx.obj["parameters"], zip(it, it)))
     if param_initial_values:
@@ -296,13 +316,12 @@ def space(
         print("First synthesis succeeded")
 
     metrics = ctx.obj["point_evaluator"].get_metrics()
-
     fitness_evaluator = FitnessEvaluator(
         ctx.obj["point_evaluator"],
         disable=disable_approximate,
         controller=controller_model,
         estimator=estimation_model,
-        controller_mab_weight=controller_mab_weight,
+        controller_mab_weight=not disable_controller_mab_weight,
     )
 
     execution_time = optimize(
